import json
import logging
logger = logging.getLogger('data')


class BaseConsumer(object):
    def __init__(self, conf=None):
        pass

    @classmethod
    def from_config(cls, opt):
        config = opt.get('config')
        return cls(conf=config)

    def stop(self):
        pass


class Printer(BaseConsumer):
    """
    Print the data received on stdout.
    """
    def process(self, msg):
        if isinstance(msg, str):
            logger.debug(msg)
        else:
            logger.debug(json.dumps(msg))


class SessionPrinter(BaseConsumer):
    """
    Print the data received on stdout.
    """

    def __init__(self, conf=None):
        super().__init__(conf)
        # признак что выводим только id изменяемых данных, а не всю запись
        self.only_ids = conf.getboolean('pgdatalogger', 'only_ids')

    def process(self, msg):
        # найдем среди изменений таблицу commit_trigger.trigger_called
        # из нее достанем параметры сессии - они должны быть в каждой транзакции
        session = next((block['record'] for block in msg['changes']
                        if block['table'] == 'trigger_called'), {})
        for block in msg['changes']:
            if block['table'] != 'trigger_called':
                if self.only_ids and block['record']:
                    del block['record']
                logger.debug(f'{json.dumps(session)} | {json.dumps(block)}')
